@@ -3,8 +3,9 @@ use Mojo::Base 'LinkEmbedder::Link';
 
 use constant DEBUG => $ENV{LINK_EMBEDDER_DEBUG} || 0;
 
+sub force_secure {0}
 has provider_name => 'Shadowcat';
-has provider_url => sub { Mojo::URL->new('http://shadow.cat/') };
+has provider_url  => sub { Mojo::URL->new('https://shadow.cat/') };
 
 sub learn_p {
   my $self = shift;
@@ -20,8 +21,7 @@ sub _fetch_paste {
 
   $raw_url->query->param(tx => 'on');
   warn "[LinkEmbedder] Shadowcat paste URL $raw_url\n" if DEBUG;
-
-  return $self->title("Paste $paste_id")->type("rich")->ua->get_p($raw_url)->then(sub { $self->_parse_paste(shift) });
+  return $self->title("Paste $paste_id")->type("rich")->_get_p($raw_url)->then(sub { $self->_parse_paste(shift) });
 }
 
 sub _parse_paste {
